@@ -174,6 +174,21 @@ def load_model_map() -> dict[str, dict[WeightsFormat, str]]:
 
 def get_default_measured_properties() -> list[str]:
     return [
+        "is_valid",
+        "dataset_tokens_per_second_per_gpu",
+        "train_runtime",
+        "dataset_tokens_per_second",
+        # VV: the next 4 are inaccurate when terminating the job early
+        "train_samples_per_second",
+        "train_steps_per_second",
+        "train_tokens_per_second",
+        "train_tokens_per_gpu_per_second",
+        # VV: We no longer record the model_load_time
+        # "model_load_time",
+        # VV: CPU measurements
+        "cpu_compute_utilization",
+        "cpu_memory_utilization",
+        # VV: GPU measurements - these will be 0 when running on a machine without GPUs
         "gpu_compute_utilization_min",
         "gpu_compute_utilization_avg",
         "gpu_compute_utilization_max",
@@ -187,19 +202,6 @@ def get_default_measured_properties() -> list[str]:
         "gpu_power_percent_min",
         "gpu_power_percent_avg",
         "gpu_power_percent_max",
-        "cpu_compute_utilization",
-        "cpu_memory_utilization",
-        "train_runtime",
-        # VV: the next 4 are inaccurate when terminating the job early
-        "train_samples_per_second",
-        "train_steps_per_second",
-        "train_tokens_per_second",
-        "train_tokens_per_gpu_per_second",
-        # VV: We no longer record the model_load_time
-        # "model_load_time",
-        "dataset_tokens_per_second",
-        "dataset_tokens_per_second_per_gpu",
-        "is_valid",
     ]
 
 
@@ -245,138 +247,6 @@ def get_fms_hf_tuning_package(commit: str) -> str:
     return f"fms-hf-tuning@git+{FMS_HF_TUNING_REPOSITORY}@{commit}"
 
 
-def apply_exclude_package_rules(
-    exclude_packages: list[str], packages: list[str]
-) -> list[str]:
-    """Filters out packages based on a list of exclusion rules.
-
-    Args:
-        exclude_packages:
-            A list of rules for excluding package names
-        packages:
-            A list of packages to filter
-
-    Returns:
-        A new list containing only the packages that do not match any of the exclusion rules
-    """
-    if not exclude_packages:
-        return packages
-    ret = []
-
-    for candidate_package in packages:
-        # VV: Some packages look like this: "name @ file://...."
-        trimmed = candidate_package.replace(" ", "")
-        for unwanted_package in exclude_packages:
-            if (
-                trimmed.startswith((f"{unwanted_package}=", f"{unwanted_package}@"))
-                or trimmed == unwanted_package
-            ):
-                break
-        else:
-            # VV: Keep the original package
-            ret.append(candidate_package)
-
-    return ret
-
-
-def get_pinned_packages(
-    path_requirements: str,
-    override_fms_hf_tuning: str | None = None,
-    ensure_aim: bool = True,
-    exclude_packages: list[str] | None = None,
-) -> list[str]:
-    """Extracts the pinned packages from a path_requirements file
-
-    Args:
-        path_requirements:
-            Path to the requirements.txt file containing the pinned packages (one package per line, a-la pip)
-        override_fms_hf_tuning:
-            If set, overrides the `fms-hf-tuning` pinned package from the contents of the requirements.txt file
-        ensure_aim:
-            If set, ensures that the dependencies include the aim python package.
-        exclude_packages:
-            Packages to exclude from installation
-    Returns:
-        An array consisting of pinned packages a-la pip
-    """
-
-    with open(path_requirements, encoding="utf-8") as f:
-        packages = [x.strip() for x in f if x.strip() and not x.startswith("#")]
-
-    def find_matching_packages(package_name: str, packages: list[str]) -> list[str]:
-        return [
-            x
-            for x in packages
-            if x.startswith((f"{package_name}=", f"{package_name} "))
-            or x == package_name
-        ]
-
-    if override_fms_hf_tuning:
-        exclude_packages = [*list(exclude_packages or []), "fms-hf-tuning"]
-
-    packages = apply_exclude_package_rules(exclude_packages, packages)
-
-    if override_fms_hf_tuning:
-        packages.append(override_fms_hf_tuning)
-
-    if ensure_aim and len(find_matching_packages("aim", packages)) == 0:
-        packages.append("aim")
-
-    return packages
-
-
-def get_ray_environment(
-    path_requirements: str | None,
-    override_fms_hf_tuning: str | None,
-    ensure_aim: bool = True,
-    exclude_packages: list[str] | None = None,
-    backend: typing.Literal["uv", "pip"] = "pip",
-) -> dict[str, typing.Any]:
-    """Builds a ray-environment
-
-    Args:
-        path_requirements:
-            Path to the requirements.txt file containing the pinned packages (one package per line, a-la pip). If
-            unset then env["pip"]["packages"] will be empty. Path can be relative to parent of __file__
-        override_fms_hf_tuning:
-            If set, overrides the `fms-hf-tuning` pinned package from the contents of the requirements.txt file
-        ensure_aim:
-            If set, ensures that the dependencies include the aim python package.
-        exclude_packages:
-            Packages to exclude from installation
-        backend:
-            Which backend to use when building the ray environment
-    Returns:
-        A dictionary representing a Ray environment
-    """
-    # VV: Do not switch on pip_check.
-    ray_environment = {
-        "env_vars": {"AIM_UI_TELEMETRY_ENABLED": "0"},
-        backend: {"packages": []},
-    }
-
-    if backend == "pip":
-        ray_environment["env_vars"]["PIP_NO_BUILD_ISOLATION"] = "0"
-    elif backend == "uv":
-        ray_environment[backend]["uv_pip_install_options"] = ["--no-build-isolation"]
-    else:
-        raise NotImplementedError("Unknown ray environment backend", backend)
-
-    if path_requirements:
-        ray_environment[backend]["packages"].extend(
-            get_pinned_packages(
-                path_requirements=os.path.join(
-                    os.path.dirname(__file__), path_requirements
-                ),
-                exclude_packages=exclude_packages,
-                override_fms_hf_tuning=override_fms_hf_tuning,
-                ensure_aim=ensure_aim,
-            )
-        )
-
-    return ray_environment
-
-
 def get_fms_hf_tuning_src(fms_hf_tuning_version: str) -> str:
     # VV: TODO: Generate links to pypi if fms_hf_tuning_version is a valid pypi version
     return FMS_HF_TUNING_VERSION[fms_hf_tuning_version]
