@@ -4,8 +4,10 @@
 import os
 import typing
 
-import tuning.config.configs
 import tuning.sft_trainer
+from tuning.config.tracker_configs import (
+    TrackerConfigFactory,
+)
 
 if typing.TYPE_CHECKING:
     import transformers.trainer_callback
@@ -24,22 +26,26 @@ def parse_arguments_and_execute_wrapper(
         training_args,
         trainer_controller_args,
         tune_config,
-        quantization_config,
+        file_logger_config,
+        _aim_config,
+        hf_resource_scanner_config,
         quantized_lora_config,
         fusedops_kernels_config,
         attention_and_distributed_packing_config,
         fast_moe_config,
-        tracker_configs,
-        exp_metadata,
+        _mlflow_config,
+        _exp_metadata,
     ) = tuning.sft_trainer.parse_arguments(parser, job_config)
 
-    del exp_metadata
-
     if not os.path.isdir(training_args.output_dir):
         os.makedirs(training_args.output_dir, exist_ok=True)
 
-    training_args = typing.cast(tuning.config.configs.TrainingArguments, training_args)
-    training_args.trackers = []
+    tracker_configs = TrackerConfigFactory(
+        hf_resource_scanner_config=hf_resource_scanner_config,
+    )
+
+    tracker_configs.file_logger_config = file_logger_config
+    tracker_configs.aim_config = None
 
     metadata = {}
 
@@ -48,7 +54,6 @@ def parse_arguments_and_execute_wrapper(
         data_args=data_args,
         train_args=training_args,
         peft_config=tune_config,
-        quantization_config=quantization_config,
         trainer_controller_args=trainer_controller_args,
         tracker_configs=tracker_configs,
         additional_callbacks=callbacks,
